pub enum AttachError {
Io(Error),
Termios(Errno),
}Expand description
Errors produced while entering or restoring raw terminal mode.
Variants
Io(Error)
Duplicating the target file descriptor failed before raw mode was applied.
Termios(Errno)
A termios syscall failed while applying or restoring raw mode.