pub enum AutoStartError {
Client(ClientError),
BinaryPath(Error),
Launch {
path: PathBuf,
error: Error,
},
TimedOut {
socket_path: PathBuf,
waited: Duration,
},
}Expand description
Errors raised while auto-starting or connecting to the RMUX server.
Variants
Client(ClientError)
The client transport failed before or during readiness polling.
BinaryPath(Error)
Resolving the rmux binary path failed.
Launch
Re-executing the hidden daemon process failed.
Fields
TimedOut
The socket never became reachable before the readiness deadline.