AutoStartConfig

Struct AutoStartConfig 

pub struct AutoStartConfig { /* private fields */ }
Config loading policy to pass to a newly auto-started hidden daemon.

Implementations

Source

impl AutoStartConfig

pub const fn disabled() -> Self

Builds a policy that leaves startup config loading disabled.

pub fn default_files(quiet: bool, cwd: Option<PathBuf>) -> Self

Builds a policy that loads RMUX’s default startup config search path.

pub fn custom_files( files: Vec<PathBuf>, quiet: bool, cwd: Option<PathBuf>, ) -> Self

Builds a policy that loads the explicit top-level -f files.

pub const fn with_web_port(self, port: u16) -> Self

Overrides the web-share listener port for a newly auto-started daemon.

pub fn with_web_frontend(self, frontend: String) -> Self

Overrides the frontend origin used by newly auto-started web shares.

pub const fn with_web_required(self) -> Self

Requires a daemon compiled with web-share support for this autostart.