pub fn default_socket_path() -> Result<PathBuf, ClientError>Expand description
Computes the default RMUX client socket path.
The path uses an rmux-specific per-user directory so an rmux client never speaks the rmux wire protocol to a real tmux server.