Module nested

Module nested 

Nested-session detection via inherited multiplexer environment.

Structs

NestedContextError
Error returned when a command requires a nested client context.

Enums

ClientContext
The client context inferred from inherited multiplexer environment.
ClientContextParent
The inherited multiplexer environment that made the client nested.

Functions

detect_context
Detects the client context by inspecting inherited multiplexer environment.
detect_parent
Detects which inherited multiplexer environment, if any, is present.
ensure_nested_context
Returns an error when the supplied context is not nested.
require_nested_context
Detects the current client context and validates that it is nested.