pub fn require_nested_context() -> Result<(), NestedContextError>Expand description
Detects the current client context and validates that it is nested.
pub fn require_nested_context() -> Result<(), NestedContextError>Detects the current client context and validates that it is nested.