AutoStartConfig

Struct AutoStartConfig 

pub struct AutoStartConfig { /* private fields */ }
Config loading policy to pass to a newly auto-started hidden daemon.

Implementations

Source

impl AutoStartConfig

pub const fn disabled() -> Self

Builds a policy that leaves startup config loading disabled.

pub fn default_files(quiet: bool, cwd: Option<PathBuf>) -> Self

Builds a policy that loads RMUX’s default startup config search path.

pub fn custom_files( files: Vec<PathBuf>, quiet: bool, cwd: Option<PathBuf>, ) -> Self

Builds a policy that loads the explicit top-level -f files.