Nested-session detection via inherited multiplexer environment.
Structs
- Nested
Context Error - Error returned when a command requires a nested client context.
Enums
- Client
Context - The client context inferred from inherited multiplexer environment.
- Client
Context Parent - The inherited multiplexer environment that made the client nested.
Functions
- detect_
context - Detects the client context by inspecting inherited multiplexer environment.
- detect_
parent - Detects which inherited multiplexer environment, if any, is present.
- ensure_
nested_ context - Returns an error when the supplied context is not nested.
- require_
nested_ context - Detects the current client context and validates that it is nested.