Module nested

Module nested 

Nested-session detection via $RMUX.

Structs

NestedContextError
Error returned when a command requires a nested client context.

Enums

ClientContext
The client context inferred from the $RMUX environment variable.

Functions

detect_context
Detects the client context by inspecting the $RMUX environment variable.
ensure_nested_context
Returns an error when the supplied context is not nested.
require_nested_context
Detects the current client context and validates that it is nested.