Nested-session detection via $RMUX.
Structs
- Nested
Context Error - Error returned when a command requires a nested client context.
Enums
- Client
Context - The client context inferred from the
$RMUXenvironment variable.
Functions
- detect_
context - Detects the client context by inspecting the
$RMUXenvironment variable. - ensure_
nested_ context - Returns an error when the supplied context is not nested.
- require_
nested_ context - Detects the current client context and validates that it is nested.